@@ -15,7 +15,7 @@
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
-void  close_optfile(void);
-char  *rdoptfile(const char *, const char *);
-FILE  *open_cfile(const char *, const char *);
-FILE  *open_icfile(void);
+extern	void  close_optfile(void);
+extern	char  *rdoptfile(const char *, const char *);
+extern	FILE  *open_cfile(const char *, const char *);
+extern	FILE  *open_icfile(void);
