@@ -41,12 +41,6 @@
 #include "listperms.h"
 #include "rcgilib.h"
 
-uid_t	Daemuid,
-	Realuid,
-	Effuid;
-
-DEF_DISPOPTS;
-
 int	nopage = -1,
 	headerflag = -1;
 
@@ -60,8 +54,6 @@ struct	apispdet	mypriv;
 
 char	bigbuff[200];
 
-FILE	*Cfile;
-
 static	char	*localptr;
 
 int		Njobs, Nptrs;
@@ -71,13 +63,13 @@ struct	ptr_with_slot	*ptr_sl_list;
 
 /* For when we run out of memory.....  */
 
-void	nomem(void)
+void  nomem()
 {
 	fprintf(stderr, "Ran out of memory\n");
 	exit(E_NOMEM);
 }
 
-void	fmt_setup(void)
+void  fmt_setup()
 {
 	if  (!formatstring)  {
 		if  (!(formatstring = html_inistr("format", (char *) 0)))
@@ -85,7 +77,7 @@ void	fmt_setup(void)
 	}
 }
 
-extern char *	hex_disp(const classcode_t, const int);
+extern char *hex_disp(const classcode_t, const int);
 typedef	unsigned	fmt_t;
 #define	LOTSANDLOTS	99999999L	/* Maximum page number */
 #define	INLINE_SQLIST
@@ -155,7 +147,7 @@ typedef	unsigned	fmt_t;
 #include "inline/jfmt_sizek.c"
 #include "inline/jfmt_krchd.c"
 
-static fmt_t	fmt_jobno(const struct spq *jp, const int fwidth)
+static fmt_t  fmt_jobno(const struct spq *jp, const int fwidth)
 {
 	if  (jp->spq_netid != dest_hostid)
 		sprintf(bigbuff, "%s:%ld", look_host(jp->spq_netid), (long) jp->spq_job);
@@ -166,7 +158,7 @@ static fmt_t	fmt_jobno(const struct spq *jp, const int fwidth)
 
 #include "inline/jfmt_oddev.c"
 
-static fmt_t	fmt_printer(const struct apispq *jp, const int fwidth)
+static fmt_t  fmt_printer(const struct apispq *jp, const int fwidth)
 {
 	if  (jp->apispq_dflags & APISPQ_PQ)  {
 		struct	apispptr  *pp = find_ptr(jp->apispq_pslot);
@@ -203,7 +195,7 @@ static fmt_t	fmt_printer(const struct apispq *jp, const int fwidth)
 #include "inline/jfmt_ptime.c"
 #include "inline/jfmt_write.c"
 
-static  fmt_t  fmt_orighost(const struct apispq *jp, const int fwidth)
+static fmt_t  fmt_orighost(const struct apispq *jp, const int fwidth)
 {
 	if  (jp->apispq_jflags & HT_ROAMUSER)
 		sprintf(bigbuff, "(%s)", jp->apispq_uname);
@@ -211,7 +203,7 @@ static  fmt_t  fmt_orighost(const struct apispq *jp, const int fwidth)
 	return  0;
 }
 
-static  int  get_delim(const struct apispq *jp, int *num, int *lng, char **delimp)
+static int  get_delim(const struct apispq *jp, int *num, int *lng, char **delimp)
 {
 	/* jp is an entry in job_list the way this is used */
 
@@ -237,7 +229,7 @@ static  int  get_delim(const struct apispq *jp, int *num, int *lng, char **delim
 	return  1;
 }
 
-static  fmt_t  fmt_delimnum(const struct spq *jp, const int fwidth)
+static fmt_t  fmt_delimnum(const struct spq *jp, const int fwidth)
 {
 	char	*delim;
 	int	ndelim = 1, lng;
@@ -248,7 +240,7 @@ static  fmt_t  fmt_delimnum(const struct spq *jp, const int fwidth)
 	return  0;
 }
 
-static  fmt_t  fmt_delim(const struct spq *jp, const int fwidth)
+static fmt_t  fmt_delim(const struct spq *jp, const int fwidth)
 {
 	char	*delim;
 	int	ndelim = 1, lng;
@@ -310,7 +302,7 @@ struct	formatdef  {
 	SHORT	statecode;	/* Code number for heading if applicable */
 	char	alch;		/* Default align char */
 	char	*msg;		/* Heading */
-	unsigned	(*fmt_fn)(const struct apispq *, const int);
+	unsigned  (*fmt_fn)(const struct apispq *, const int);
 };
 
 #define	NULLCP	(char *) 0
@@ -395,7 +387,7 @@ struct	altype  {
 
 struct	altype	*commonest_align = &altypes[0];
 
-struct altype *lookup_align(const int alch)
+struct	altype	*lookup_align(const int alch)
 {
 	int	cnt;
 	for  (cnt = 0;  cnt < NALIGNTYPES;  cnt++)
@@ -415,7 +407,7 @@ int	ncolfmts, maxcolfmts;
 #define	INITCF	10
 #define	INCCF	5
 
-void	find_commonest(char *fp)
+void  find_commonest(char *fp)
 {
 	int	rvec[NALIGNTYPES];
 	int	cnt, mx = 0, ind = 0, fmch;
@@ -465,12 +457,12 @@ void	find_commonest(char *fp)
 			cflist[cnt].alstr = (char *) 0;
 }
 
-void	startrow(void)
+void  startrow()
 {
 	printf("<tr align=%s>\n", commonest_align->str);
 }
 
-void	startcell(const int celltype, const char *str)
+void  startcell(const int celltype, const char *str)
 {
 	if  (str)
 		printf("<t%c align=%s>", celltype, str);
@@ -480,7 +472,7 @@ void	startcell(const int celltype, const char *str)
 
 /* Display contents of job file.  */
 
-void	jdisplay(void)
+void  jdisplay()
 {
 	int	fcnt, jcnt;
 	unsigned	pflgs = 0;
@@ -633,10 +625,10 @@ struct	arginterp  {
 #define	AIF_NOARG	0
 #define	AIF_ARG		1
 #define	AIF_ARGLIST	2
-	int	(*arg_fn)(char *);
+	int  (*arg_fn)(char *);
 };
 
-int	perf_listformat(char *notused)
+int  perf_listformat(char *notused)
 {
 	struct	formatdef   *fp;
 	int	lett;
@@ -662,21 +654,21 @@ int	perf_listformat(char *notused)
 	exit(0);
 }
 
-extern int	perf_optselect(char *);
+extern int  perf_optselect(char *);
 
-int	set_queue(char * arg)
+int  set_queue(char *arg)
 {
 	Displayopts.opt_restrp = *arg? arg: (char *) 0;
 	return  1;
 }
 
-int	set_user(char * arg)
+int  set_user(char *arg)
 {
 	Displayopts.opt_restru = *arg? arg: (char *) 0;
 	return  1;
 }
 
-int	set_incnull(char * arg)
+int  set_incnull(char *arg)
 {
 	switch  (tolower(*arg))  {
 	case  'a':
@@ -693,7 +685,7 @@ int	set_incnull(char * arg)
 	}
 }
 
-int	set_loco(char * arg)
+int  set_loco(char *arg)
 {
 	switch  (tolower(*arg))  {
 	case  'l':case 'y':case '1':
@@ -707,7 +699,7 @@ int	set_loco(char * arg)
 	}
 }
 
-int	set_prininc(char * arg)
+int  set_prininc(char *arg)
 {
 	switch  (tolower(*arg))  {
 	case  'n':
@@ -724,7 +716,7 @@ int	set_prininc(char * arg)
 	}
 }
 
-int	set_pagecnt(char * arg)
+int  set_pagecnt(char *arg)
 {
 	switch  (tolower(*arg))  {
 	case  'y':case '1':
@@ -738,7 +730,7 @@ int	set_pagecnt(char * arg)
 	}
 }
 
-int	set_header(char * arg)
+int  set_header(char *arg)
 {
 	switch  (tolower(*arg))  {
 	case  'y':case '1':
@@ -752,13 +744,13 @@ int	set_header(char * arg)
 	}
 }
 
-int	set_format(char * arg)
+int  set_format(char *arg)
 {
 	formatstring = arg;
 	return  1;
 }
 
-extern void	perf_listprfm(char *, char *, char *);
+extern void  perf_listprfm(char *, char *, char *);
 
 struct	arginterp  argtypes[] =  {
 	{	"format",	AIF_ARG,	set_format	},
@@ -774,13 +766,13 @@ struct	arginterp  argtypes[] =  {
 	{	"listformat",	AIF_NOARG,	perf_listformat	}
 };
 
-int	perf_optselect(char * notused)
+int  perf_optselect(char *notused)
 {
 	html_out_param_file("setopts", 1, 0, html_cookexpiry());
 	exit(0);
 }
 
-void	interp_args(char ** args)
+void  interp_args(char **args)
 {
 	char	**ap, *arg, *cp = (char *) 0;
 	int	cnt;
@@ -814,7 +806,7 @@ void	interp_args(char ** args)
    taken from the job "jobnum" or defaults if null
    Copies, form, printer, form list, printer list */
 
-void	perf_listprfm(char * tmpl, char * jsfunc, char * jobnum)
+void  perf_listprfm(char *tmpl, char *jsfunc, char *jobnum)
 {
 	int	def_copies = 1, def_pri, def_supp = 0;
 	char	*def_ptr, *def_form, *def_tit = "";
@@ -884,13 +876,13 @@ void	perf_listprfm(char * tmpl, char * jsfunc, char * jobnum)
 
 /* Ye olde main routine.  */
 
-MAINFN_TYPE	main(int argc, char **argv)
+MAINFN_TYPE  main(int argc, char **argv)
 {
 	char	**newargs;
 	unsigned	Jaccess_flags = 0;
 	int_ugid_t	chku;
 
-	versionprint(argv, "$Revision: 1.1.1.1 $", 0);
+	versionprint(argv, "$Revision: 1.1 $", 0);
 
 	if  ((progname = strrchr(argv[0], '/')))
 		progname++;
