@@ -52,20 +52,12 @@
 #include "cfile.h"
 #include "displayopt.h"
 #include "cgifndjb.h"
-#ifdef	SHAREDLIBS
 #include "xfershm.h"
-#endif
 
 #ifndef	PATH_MAX
 #define	PATH_MAX	1024
 #endif
 
-uid_t	Daemuid,
-	Realuid,
-	Effuid;
-
-DEF_DISPOPTS;
-
 int		nopage,
 		headerflag;
 
@@ -94,37 +86,23 @@ char	*Curr_pwd;
 
 static	char	*localptr;
 
-FILE	*Cfile;
-
 #define	IPC_MODE	0600
 
-int	Ctrl_chan;
-#ifndef	USING_FLOCK
-int	Sem_chan;
-#endif
+extern  int  spitoption(const int, const int, FILE *, const int, const int);
+extern  int  proc_save_opts(const char *, const char *, void (*)(FILE *, const char *));
 
-struct	jshm_info	Job_seg;
-struct	pshm_info	Ptr_seg;
-
-#ifdef	SHAREDLIBS
-struct	xfershm		*Xfer_shmp;
-#endif
-
-int	spitoption(const int, const int, FILE *, const int, const int);
-int	proc_save_opts(const char *, const char *, void (*)(FILE *, const char *));
-
-int	rdpgfile(const struct spq *, struct pages *, char **, unsigned *, LONG **);
-FILE	*net_feed(const int, const netid_t, const slotno_t, const jobno_t);
+extern  int  rdpgfile(const struct spq *, struct pages *, char **, unsigned *, LONG **);
+extern  FILE *net_feed(const int, const netid_t, const slotno_t, const jobno_t);
 
 /* For when we run out of memory.....  */
 
-void	nomem(void)
+void  nomem()
 {
 	fprintf(stderr, "Ran out of memory\n");
 	exit(E_NOMEM);
 }
 
-static void	getwanted(char ** argv)
+static void  getwanted(char **argv)
 {
 	char	**ap;
 	struct	jobswanted  *wp;
@@ -157,7 +135,7 @@ static void	getwanted(char ** argv)
 	nwanted = actw;
 }
 
-static int	iswanted(const struct spq * jp)
+static int  iswanted(const struct spq *jp)
 {
 	unsigned	cnt;
 
@@ -205,7 +183,7 @@ typedef	unsigned	fmt_t;
 struct	formatdef  {
 	SHORT	statecode;	/* Code number for heading if applicable */
 	char	*msg;		/* Heading */
-	unsigned	(*fmt_fn)(const struct spq *, const int);
+	unsigned  (*fmt_fn)(const struct spq *, const int);
 };
 
 #define	NULLCP	(char *) 0
@@ -270,7 +248,7 @@ struct	formatdef
 
 /* Display contents of job file.  */
 
-void	jdisplay(void)
+void  jdisplay()
 {
 	int	jcnt;
 	char	*fp;
@@ -456,7 +434,7 @@ void	jdisplay(void)
    Return 0 if not in range.
    Return 1 if in range. */
 
-static int	inrange(const unsigned page)
+static int  inrange(const unsigned page)
 {
 	char	*cp;
 	ULONG	num1, num2;
@@ -490,7 +468,7 @@ static int	inrange(const unsigned page)
 	return  lessr? 0: -1;
 }
 
-static void	viewj(const struct spq * jp)
+static void  viewj(const struct spq *jp)
 {
 	int		haspages = 0;
 	char		*delim = (char *) 0;
@@ -569,7 +547,7 @@ endview:
 	}
 }
 
-void	check_viewj(const struct spq * jp)
+void  check_viewj(const struct spq *jp)
 {
 	if  (!(mypriv->spu_flgs & PV_VOTHERJ)  &&  strcmp(Realuname, jp->spq_uname) != 0)  {
 		disp_arg[0] = jp->spq_job;
@@ -589,7 +567,7 @@ void	check_viewj(const struct spq * jp)
 	viewj(jp);
 }
 
-static void	doview(void)
+static void  doview()
 {
 	unsigned  jcnt;
 
@@ -686,7 +664,7 @@ o_viewjob,	o_noviewjob,	o_viewpages,
 o_freezecd,	o_freezehd
 };
 
-void	spit_options(FILE *dest, const char *name)
+void  spit_options(FILE *dest, const char *name)
 {
 	int	cancont = 0;
 	fprintf(dest, "%s", name);
@@ -723,14 +701,14 @@ void	spit_options(FILE *dest, const char *name)
 
 /* Ye olde main routine.  */
 
-MAINFN_TYPE	main(int argc, char **argv)
+MAINFN_TYPE  main(int argc, char **argv)
 {
 	char	*spdir;
 #if	defined(NHONSUID) || defined(DEBUG)
 	int_ugid_t	chk_uid;
 #endif
 
-	versionprint(argv, "$Revision: 1.1.1.1 $", 0);
+	versionprint(argv, "$Revision: 1.2 $", 0);
 
 	if  ((progname = strrchr(argv[0], '/')))
 		progname++;
